﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Net;
using System.Json;
using System.Collections.ObjectModel;
using System.Windows.Browser;

namespace ToDo_List_Tutorial
{
	public partial class MainPage : UserControl
	{
        WebClient wc = new WebClient();
        ObservableCollection<ToDoItem> myToDoList = new ObservableCollection<ToDoItem>();
        string baseURI = "<website_location_holding_your_php_files>";
        System.Windows.Threading.DispatcherTimer dt = new System.Windows.Threading.DispatcherTimer();

        public MainPage()
		{
			// Required to initialize variables
			InitializeComponent();

            wc.DownloadStringCompleted += new DownloadStringCompletedEventHandler(wc_DownloadStringCompleted);

            wc.DownloadStringAsync(new Uri(baseURI + "get_todo_items.php"));
		}

        void wc_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            // Got to make sure we turn the addTodo button back on, even
            //      if we get an error from the result
            addTodo.IsEnabled = true;

            if (e.Error == null && e.Result!= "")
            {
                JsonValue completeResult = JsonPrimitive.Parse(e.Result);
                string resultType = completeResult["returnType"].ToString().Replace('"', ' ').Trim();
                if (resultType == "todoItems")
                {
                    myToDoList.Clear();

                    JsonArray toDoItemsJson = (JsonArray)completeResult["results"];
                    foreach (JsonValue todoItemJson in toDoItemsJson)
                    {
                        ToDoItem thisTodo = new ToDoItem();

                        if (todoItemJson["ToDoIndex"] != null)
                            thisTodo.toDoID = Convert.ToInt32(todoItemJson["ToDoIndex"].ToString().Replace('"', ' ').Trim());
                        if (todoItemJson["TodoText"] != null)
                            thisTodo.toDoDescription = todoItemJson["TodoText"].ToString().Replace('"', ' ').Trim();
                        if (todoItemJson["IsDone"] != null)
                        {
                            int isDoneInt =  Convert.ToInt32(todoItemJson["IsDone"].ToString().Replace('"', ' ').Trim());
                            if(isDoneInt == 0){
                                thisTodo.isDone = false;
                            } else if (isDoneInt == 1){
                                thisTodo.isDone = true;
                            }                           
                        }
                        myToDoList.Add(thisTodo);
                    }
                    ToDoList.ItemsSource = myToDoList;
                }
                else if (resultType == "addToDoItem")
                {                    
                    string webServiceStatus = completeResult["status"].ToString().Replace('"', ' ').Trim();
                    if(!webServiceStatus.StartsWith("ERROR"))
                    {
                        ToDoItem newToDoItem = new ToDoItem();
                        newToDoItem.toDoID = Convert.ToInt32(completeResult["newToDoItemID"].ToString().Replace('"', ' ').Trim());
                        newToDoItem.toDoDescription = completeResult["newToDoText"].ToString().Replace('"', ' ').Trim();
                        string boolChecker = completeResult["newToDoItemID"].ToString().Replace('"', ' ').Trim();
                        if (boolChecker == "false")
                        {
                            newToDoItem.isDone = false;
                        }
                        else if (boolChecker == "true")
                        {
                            newToDoItem.isDone = true;
                        }
                        myToDoList.Insert(0, newToDoItem);
                    }
                }
            }
        }

		private void toDoItemComplete(object sender, System.Windows.RoutedEventArgs e)
		{
            if (!wc.IsBusy && ((CheckBox)sender).IsFocused)
            {
                wc.DownloadStringAsync(new Uri(baseURI + "change_status.php?newStatus=true&todoID=" + ((CheckBox)sender).Tag.ToString()));
            }
		}

		private void toDoItemIncomplete(object sender, System.Windows.RoutedEventArgs e)
		{
            if (!wc.IsBusy && ((CheckBox)sender).IsFocused)
            {
                wc.DownloadStringAsync(new Uri(baseURI + "change_status.php?newStatus=false&todoID=" + ((CheckBox)sender).Tag.ToString()));
            }
		}

        private void changeToDoStatus(int toDoIndex, bool newStatus)
        {

        }

		private void IsKeyEnter(object sender, System.Windows.Input.KeyEventArgs e)
		{
            // Must check to see if the web client is busy. If it is, we won't cause
            //      an error by calling it again.
            if (e.Key.Equals(Key.Enter) && !(wc.IsBusy))
            {
                this.AddNewTodoItem();                
            }
		}

        private void AddNewTodoItem()
        {
            if (TodoText.Text != "" && TodoText.Text != "Type new to-do here")
            {
                //Turn the validation text off
                this.TodoValidation.Visibility = Visibility.Collapsed;

                // We'll turn off the addTodo functionality until the web client
                //      is done adding the item.
                addTodo.IsEnabled = false;

                //Call the web service to add a new item
                string newToDoText = HttpUtility.UrlEncode(TodoText.Text);
                wc.DownloadStringAsync(new Uri(baseURI + "add_todo_item.php?todo=" + newToDoText));
                
                //Reset the TextBox
                TodoText.Text = "Type new to-do here";
                TodoText.Foreground = new SolidColorBrush(Color.FromArgb(255, 169, 169, 169));
            }
            else
            {
                this.TodoValidation.Visibility = Visibility.Visible;
            }
        }

		private void changeText(object sender, System.Windows.RoutedEventArgs e)
		{
			TextBox thisTextBox = (TextBox)sender;
			if(thisTextBox.Text == "Type new to-do here")
			{
				thisTextBox.Text = "";
                thisTextBox.Foreground = new SolidColorBrush(Color.FromArgb(255, 0, 0, 0));
			}
		}

		private void click_addTodo(object sender, System.Windows.RoutedEventArgs e)
		{
            // Must check to see if the web client is busy. If it is, we won't cause
            //      an error by calling it again.
            if (!(wc.IsBusy))
            {
                this.AddNewTodoItem();
            }
		}
	}
}